---
title: <span class="badge object-type-scalar"></span> DatetimeDefault
---
# <span class="badge object-type-scalar"></span> DatetimeDefault

Date & time: Datetime default

## Definition

```python
# Date & time: Datetime default
DatetimeDefault: typing.Literal["dateTimeAsSystem"] = "dateTimeAsSystem"
```
